---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: 'Feature request'

---

## Description
(A clear and concise description of what the feature is.)
- If the proposal is about a new dataset, provide description of what the dataset is and 
attach the basic data analysis with it.
- If the proposal is about an API, provide mock examples if possible.

## References
- list reference and related literature
- list known implementations
